Index: /trunk/src/VBox/Main/include/GuestCtrlImplPrivate.h
===================================================================
--- /trunk/src/VBox/Main/include/GuestCtrlImplPrivate.h	(revision 105891)
+++ /trunk/src/VBox/Main/include/GuestCtrlImplPrivate.h	(revision 105892)
@@ -728,5 +728,5 @@
     GuestDirectoryOpenInfo(void)
         : menmFilter(GSTCTLDIRFILTER_NONE)
-        , mFlags(0) { }
+        , mFlags(GSTCTLDIR_F_NONE) { }
 
     /** The directory path. */
@@ -736,5 +736,5 @@
     /** The filter option to use. */
     GSTCTLDIRFILTER         menmFilter;
     /** Opening flags (of type GSTCTLDIRFILTER_XXX). */
     uint32_t                mFlags;
 };
@@ -736,5 +736,5 @@
     /** The filter option to use. */
     GSTCTLDIRFILTER         menmFilter;
-    /** Opening flags (of type GSTCTLDIRFILTER_XXX). */
+    /** Opening flags (of type GSTCTLDIR_F_XXX). */
     uint32_t                mFlags;
 };
